==> tfx-0.15.0-py2-none-any.whl: tfx/orchestration/launcher/test_utils.py <==
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Common code shared by test code."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import os
import tensorflow as tf
from typing import Any, Dict, List, Optional, Text
from tfx import types
from tfx.components.base import base_component
from tfx.components.base import base_driver
from tfx.components.base import base_executor
from tfx.components.base import executor_spec
from tfx.orchestration import data_types
from tfx.types import artifact_utils
from tfx.types import channel_utils
from tfx.types import component_spec


class _FakeDriver(base_driver.BaseDriver):
  """Fake driver for testing purpose only."""

  def pre_execution(
      self,
      input_dict                           ,
      output_dict                           ,
      exec_properties                 ,
      driver_args                       ,
      pipeline_info                         ,
      component_info                          ,
  )                                :
    input_artifacts = channel_utils.unwrap_channel_dict(input_dict)
    output_artifacts = channel_utils.unwrap_channel_dict(output_dict)
    tf.io.gfile.makedirs(pipeline_info.pipeline_root)
    artifact_utils.get_single_instance(
        output_artifacts['output']).uri = os.path.join(
            pipeline_info.pipeline_root, 'output')
    return data_types.ExecutionDecision(input_artifacts, output_artifacts,
                                        exec_properties, 123, False)


class _FakeExecutor(base_executor.BaseExecutor):
  """Fake executor for testing purpose only."""

  def Do(self, input_dict                                  ,
         output_dict                                  ,
         exec_properties                 )        :
    input_path = artifact_utils.get_single_uri(input_dict['input'])
    output_path = artifact_utils.get_single_uri(output_dict['output'])
    tf.io.gfile.copy(input_path, output_path)


class _FakeComponentSpec(types.ComponentSpec):
  """Fake component spec for testing purpose only."""
  PARAMETERS = {}
  INPUTS = {'input': component_spec.ChannelParameter(type_name='InputPath')}
  OUTPUTS = {'output': component_spec.ChannelParameter(type_name='OutputPath')}


class _FakeComponent(base_component.BaseComponent):
  """Fake component for testing purpose only."""
  SPEC_CLASS = _FakeComponentSpec
  EXECUTOR_SPEC = executor_spec.ExecutorClassSpec(_FakeExecutor)
  DRIVER_CLASS = _FakeDriver

  def __init__(self,
               name      ,
               input_channel               ,
               output_channel                          = None,
               custom_executor_spec                             = None):
    output_channel = output_channel or types.Channel(
        type_name='OutputPath', artifacts=[types.Artifact('OutputPath')])
    spec = _FakeComponentSpec(input=input_channel, output=output_channel)
    super(_FakeComponent, self).__init__(
        spec=spec,
        instance_name=name,
        custom_executor_spec=custom_executor_spec)

==> tfx-0.21.1-py2-none-any.whl: tfx/orchestration/launcher/test_utils.py <==
# Lint as: python2, python3
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Common code shared by test code."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import os
from typing import Any, Dict, List, Optional, Text

import tensorflow as tf

from tfx import types
from tfx.components.base import base_component
from tfx.components.base import base_driver
from tfx.components.base import base_executor
from tfx.components.base import executor_spec
from tfx.orchestration import data_types
from tfx.types import artifact_utils
from tfx.types import channel_utils
from tfx.types import component_spec


class _InputArtifact(types.Artifact):
  TYPE_NAME = 'InputArtifact'


class _OutputArtifact(types.Artifact):
  TYPE_NAME = 'OutputArtifact'


class _FakeDriver(base_driver.BaseDriver):
  """Fake driver for testing purpose only."""

  def pre_execution(
      self,
      input_dict                           ,
      output_dict                           ,
      exec_properties                 ,
      driver_args                       ,
      pipeline_info                         ,
      component_info                          ,
  )                                :
    input_artifacts = channel_utils.unwrap_channel_dict(input_dict)
    output_artifacts = channel_utils.unwrap_channel_dict(output_dict)
    tf.io.gfile.makedirs(pipeline_info.pipeline_root)
    artifact_utils.get_single_instance(
        output_artifacts['output']).uri = os.path.join(
            pipeline_info.pipeline_root, 'output')
    return data_types.ExecutionDecision(input_artifacts, output_artifacts,
                                        exec_properties, 123, False)


class _FakeExecutor(base_executor.BaseExecutor):
  """Fake executor for testing purpose only."""

  def Do(self, input_dict                                  ,
         output_dict                                  ,
         exec_properties                 )        :
    input_path = artifact_utils.get_single_uri(input_dict['input'])
    output_path = artifact_utils.get_single_uri(output_dict['output'])
    tf.io.gfile.copy(input_path, output_path)


class _FakeComponentSpec(types.ComponentSpec):
  """Fake component spec for testing purpose only."""
  PARAMETERS = {}
  INPUTS = {'input': component_spec.ChannelParameter(type=_InputArtifact)}
  OUTPUTS = {'output': component_spec.ChannelParameter(type=_OutputArtifact)}


class _FakeComponent(base_component.BaseComponent):
  """Fake component for testing purpose only."""
  SPEC_CLASS = _FakeComponentSpec
  EXECUTOR_SPEC = executor_spec.ExecutorClassSpec(_FakeExecutor)
  DRIVER_CLASS = _FakeDriver

  def __init__(self,
               name      ,
               input_channel               ,
               output_channel                          = None,
               custom_executor_spec                             = None):
    output_channel = output_channel or types.Channel(
        type=_OutputArtifact, artifacts=[_OutputArtifact()])
    spec = _FakeComponentSpec(input=input_channel, output=output_channel)
    super(_FakeComponent, self).__init__(
        spec=spec,
        instance_name=name,
        custom_executor_spec=custom_executor_spec)
